@@ -81,9 +81,15 @@ def ssm_retry(func):
                 response = func(self, *args, **kwargs)
                 display.vvv(response, host=self.host)
                 return response
+            except self._ssm_client.exceptions.TargetNotConnected as e:
+                raise AnsibleConnectionFailure(
+                    "Instance %s (%s) must be managed by Session Manager. Is SSM Agent installed and active?"
+                    % (self.instance_id, self.host),
+                    orig_exc=e,
+                )
             except (AnsibleConnectionFailure, Exception) as e:
                 if attempt == retries - 1:
-                    raise e
+                    raise AnsibleConnectionFailure(e)
 
                 delay = min((2 ** attempt) - 1, MAX_DELAY)
 
@@ -184,14 +190,12 @@ class Connection(ConnectionBase):
 
     def _connect(self):
         if not self._session_id:
-            self._s3_client = self._get_boto_client("s3")
-            self._ssm_client = self._get_boto_client("ssm")
             self.start_ssm_session()
         return self
 
-    def _get_instance_id(self):
+    def _get_instance_meta(self):
         cmd = self.get_option("host_command").replace("$HOST", self.host)
-        return to_text(subprocess.check_output(shlex.split(cmd)).strip())
+        return json.loads(to_text(subprocess.check_output(shlex.split(cmd)).strip()))
 
     def _start_process(self, cmd):
         display.vvvv(u"SSM COMMAND: {0}".format(to_text(cmd)), host=self.host)
@@ -217,7 +221,11 @@ class Connection(ConnectionBase):
         self._process.stdin.write(to_bytes("stty -echo\n" + "PS1=''\n"))
 
     def start_ssm_session(self):
-        self.instance_id = self._get_instance_id()
+        instance_meta = self._get_instance_meta()
+        self.instance_id = instance_meta["instance"]
+
+        self._s3_client = self._get_boto_client("s3")
+        self._ssm_client = self._get_boto_client("ssm", region=instance_meta["region"])
 
         display.vvv(
             u"ESTABLISH SSM CONNECTION TO: {0}".format(self.instance_id),
@@ -320,10 +328,10 @@ class Connection(ConnectionBase):
 
         return (self._process.returncode, stdout, self._flush_stderr())
 
-    def _get_boto_client(self, service):
+    def _get_boto_client(self, service, region=None):
         return boto3.Session(
             profile_name=self.get_option("profile"),
-            region_name=self.get_option("region"),
+            region_name=region or self.get_option("region"),
         ).client(service)
 
     def _get_url(self, action, key, http_method):
