@@ -1,9 +1,10 @@
 from collections import defaultdict
 
 import click
+import immutables
 
-from ..errors import CliError
-from ..helpers.config import Config, ConfigSchema
+from ..helpers.config import Config
+from ..helpers.config.config import ConfigSchema
 from ..helpers.validations import validate_resource
 from .sym import sym
 
@@ -27,13 +28,24 @@ def value_callback(ctx, value: str):
     return value
 
 
+def pformat(value, indent=0):
+    if isinstance(value, (dict, immutables.Map)):
+        lines = []
+        for k, v in value.items():
+            tabs = "\t" * indent
+            lines.append(f"\n{tabs}{k}: {pformat(v, indent=indent+1)}")
+        return "\n".join(lines)
+    else:
+        return value
+
+
 @sym.command(hidden=True, short_help="get a config value")
 @click.argument("key", callback=key_callback)
 @click.argument("value", callback=value_callback, required=False)
 def config(key: str, value: str) -> None:
     """Get a Sym config value."""
     if value is None:
-        click.echo(Config.instance().get(key))
+        click.echo(pformat(Config.instance().get(key)))
     else:
         Config.instance()[key] = value
 
