@@ -25,6 +25,7 @@ from ..version import __version__
 @click.option(
     "--debug", is_flag=True, help="enable verbose debugging", envvar="SYM_DEBUG"
 )
+@click.option("--aws-region", envvar="AWS_REGION", hidden=True)
 @click.option(
     "--log-dir",
     type=click.Path(dir_okay=True, file_okay=False),
@@ -40,6 +41,7 @@ def sym(
     saml_client_name: SAMLClientName,
     debug: bool,
     resource: str,
+    aws_region: str,
     log_dir: Optional[str],
 ) -> None:
     """Access resources managed by Sym workflows.
@@ -50,3 +52,4 @@ def sym(
     options.saml_client_type = choose_saml_client(saml_client_name, none_ok=True)
     options.debug = debug
     options.log_dir = log_dir
+    options.aws_region = aws_region
