@@ -1,6 +1,6 @@
 import inspect
 import logging
-from dataclasses import dataclass, field
+from dataclasses import dataclass, field, replace
 from typing import Dict, Optional, Sequence, Type
 
 from ..errors import SAMLClientNotFound
@@ -10,24 +10,31 @@ from ..saml_clients.saml_client import SAMLClient
 
 
 @dataclass
-class GlobalOptions:
-    saml_client_type: Type[SAMLClient] = field(
-        default_factory=lambda: choose_saml_client("auto", none_ok=True)
-    )
-    saml_clients: Dict[str, SAMLClient] = field(default_factory=dict)
-
+class GlobalOptionsBase:
     debug: bool = False
-    log_dir: Optional[str] = None
+
+    def clone(self, **kwargs):
+        return replace(self, **kwargs)
 
     def dprint(self, *s: Sequence[str], **kwargs):
         s = list(map(str, filter(None, s)))
-        if s and self.debug:
+        if (s or kwargs) and self.debug:
             message = " ".join(s)
             if kwargs:
                 message += ": " + ",".join([f"{k}={v}" for k, v in kwargs.items()])
             mod = inspect.getmodule(inspect.stack()[1][0])
             logging.getLogger(mod.__name__).debug(message)
 
+
+@dataclass
+class GlobalOptions(GlobalOptionsBase):
+    saml_client_type: Type[SAMLClient] = field(
+        default_factory=lambda: choose_saml_client("auto", none_ok=True)
+    )
+    saml_clients: Dict[str, SAMLClient] = field(default_factory=dict)
+    log_dir: Optional[str] = None
+    aws_region: Optional[str] = None
+
     def create_saml_client(self, resource: str) -> SAMLClient:
         if not self.saml_client_type:
             raise SAMLClientNotFound()
@@ -37,4 +44,8 @@ class GlobalOptions:
         return self.saml_clients[resource]
 
     def to_dict(self):
-        return {"debug": self.debug, "saml_client": str(self.saml_client_type)}
+        return {
+            "debug": self.debug,
+            "saml_client": str(self.saml_client_type),
+            "aws_region": str(self.aws_region),
+        }
