@@ -4,6 +4,7 @@ import click
 from click_option_group import MutuallyExclusiveOptionGroup
 
 from sym.cli.constants.env import SYM_USE_CONTROL_MASTER
+from sym.cli.errors import CliError
 from sym.cli.helpers.ssh import check_ssh_version
 from sym.cli.helpers.util import flow
 
@@ -29,34 +30,39 @@ def config_option(
     return decorator
 
 
-def _resource_callback(ctx, resource: str, saml_client_name: str, throw=True):
-    if resource is None:
-        return None
+def _resource_arg_callback(ctx, _param, resource: str):
+    """
+    The resource *arg* callback raises an exception when the user isn't logged in,
+    or when the supplied resource isn't valid for the logged in user.
+    Otherwise, it returns the resource.
+    """
     if not Config.is_logged_in():
-        return resource
-    saml_client = choose_saml_client(saml_client_name)
-    if not saml_client.validate_resource(resource):
-        if throw:
-            raise click.BadParameter(f"Invalid resource: {resource}")
-        else:
-            return None
+        raise CliError("Please run `sym login` first")
+    if resource is None:
+        # We do some really complicated stuff in SymGroup to automagically update args so that
+        # "resource" doesn't need to follow the strict rules of being a positional arg.
+        # For "ansible-playbook" and "ssh" commands, this can result in this callback getting invoked
+        # twice, once with "None" value here.
+        return None
+    saml_client = choose_saml_client(ctx.parent.params["saml_client_name"])
+    if not resource or not saml_client.validate_resource(resource):
+        raise click.BadParameter(f"Invalid resource: {resource}")
     return resource
 
 
-def _resource_option_callback(ctx, _param, resource: str):
-    return _resource_callback(ctx, resource, ctx.params["saml_client_name"], throw=False)
-
-
-def _resource_arg_callback(ctx, _param, resource: str):
-    return _resource_callback(ctx, resource, ctx.parent.params["saml_client_name"])
-
-
 def resource_option(f):
+    """
+    Used by the root command only. Subcommands that require a positional resource argument
+    can get confused when the resource is provided via env var and is followed with arbitrary
+    other args, so we have a special decorator in SymGroup copy the option into the
+    right position. We don't use a callback or perform any special validation here,
+    that validation will be performed when a subcommand uses the
+    resource_argument decorator.
+    """
     option_decorator = click.option(
         "--resource",
         help="the Sym resource to use",
         envvar=get_resource_env_vars(),
-        callback=_resource_option_callback,
         default=lambda: Config.get_default("resource"),
         cls=EnvvarOption,
     )
@@ -64,7 +70,15 @@ def resource_option(f):
 
 
 def resource_argument(f):
-    option_decorator = click.argument("resource", callback=_resource_arg_callback)
+    option_decorator = click.argument(
+        "resource",
+        callback=_resource_arg_callback,
+        envvar=get_resource_env_vars(),
+        # We set required=False to ensure that the callback is always invoked. In the case where a
+        # custom env var is used to specify the resource, but the user is not logged in, the callback
+        # will correctly return a login error, rather than a missing argument error.
+        required=False,
+    )
     return option_decorator(f)
 
 
@@ -103,7 +117,7 @@ def ansible_options(f):
         click.option(
             "--forks",
             help="number of parallel subprocesses for ansible",
-            default=15,
+            default=10,
         ),
     ]
     return flow(options, f)
