@@ -100,6 +100,28 @@ PARAMS: Dict[str, OrgParams] = {
             ),
         },
     },
+    "healthy-health": {
+        "resource_env_var": "ENVIRONMENT",
+        "users": {"ssh": "ubuntu"},
+        "domain": "healthy-health.co",
+        "aws_saml_url": (
+            "https://healthy-health.okta.com/home/amazon_aws/0oagrj7yFaVtJoI2N5d5/272"
+        ),
+        "aws_okta_params": {
+            "mfa_provider": "OKTA",
+            "mfa_factor_type": "push",
+            "assume_role_ttl": "1h",
+            "session_ttl": "30m",
+        },
+        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
+        "profiles": {
+            "prod": Profile(
+                display_name="Prod",
+                region="us-east-1",
+                arn="arn:aws:iam::223440862848:role/ssm-healthy-health-user-prod",
+            ),
+        },
+    },
 }
 
 
