@@ -27,6 +27,11 @@ class AutoTagCommand(Command):
             return super().invoke(ctx)
 
     def parse_args(self, ctx, args):
+        """
+        To work around https://github.com/pallets/click/issues/714, we are doing a trick:
+        we always parse a resource *option* from the root command, and then we sometimes
+        rewrite the args passed to a child command before parsing the resource *argument*.
+        """
         if (
             self.params
             and (resource := ctx.parent.params.get("resource"))
