@@ -4,9 +4,14 @@ from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
-from ..errors import FailedSubprocessError, SamlClientNotSetup, UnavailableResourceError
+from ..errors import (
+    ExpiredCredentials,
+    FailedSubprocessError,
+    SamlClientNotSetup,
+    UnavailableResourceError,
+)
 from ..helpers.config import Config, SymConfigFile
-from ..helpers.constants import Saml2AwsNoCreds, Saml2AwsNoRoles
+from ..helpers.constants import Saml2AwsCredsExpired, Saml2AwsNoCreds, Saml2AwsNoRoles
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument, Options, keywords_to_options
 from ..helpers.params import Profile, get_saml2aws_params
@@ -15,6 +20,7 @@ from .saml_client import SAMLClient
 ErrorPatterns = {
     Saml2AwsNoRoles: UnavailableResourceError,
     Saml2AwsNoCreds: SamlClientNotSetup,
+    Saml2AwsCredsExpired: ExpiredCredentials,
 }
 
 
@@ -37,7 +43,7 @@ class Saml2Aws(SAMLClient):
         self._s2a_options = {
             "verbose": self.debug,
             "config": str(self.config_file),
-            "idp_account": "sym",
+            "idp_account": self._section_name,
             "skip_prompt": True,
         }
 
@@ -63,7 +69,7 @@ class Saml2Aws(SAMLClient):
         # saml2aws exec actually joins all the arguments into a single string and
         # runs it with the shell. So we have to use shlex.join to get around that!
         reparseable = shlex.join(keywords_to_options([*args, opts]))
-        with push_env("AWS_REGION", self.ensure_config()["sym"]["region"]):
+        with push_env("AWS_REGION", self.ensure_config()[self._section_name]["region"]):
             yield (
                 "saml2aws",
                 self._s2a_options,
@@ -82,7 +88,7 @@ class Saml2Aws(SAMLClient):
         else:
             options = self._s2a_options
             args = {}
-        with push_env("AWS_REGION", self.ensure_config()["sym"]["region"]):
+        with push_env("AWS_REGION", self.ensure_config()[self._section_name]["region"]):
             # no-op if session active when force=False
             yield "saml2aws", options, "login", args, {"force": force}
 
@@ -97,7 +103,8 @@ class Saml2Aws(SAMLClient):
         config = ConfigParser()
         config.read_dict(
             {
-                "sym": {
+                self._section_name: {
+                    "aws_profile": self._section_name,
                     "url": self.get_aws_saml_url(),
                     "provider": "Okta",
                     "skip_verify": "false",
