@@ -19,10 +19,10 @@ def test_aws_okta(
         with capture_command():
             aws_okta.exec("aws", "ssm", "start-session", target="i-0123456789abcdef")
     capture_command.assert_command(
-        "aws-okta exec sym -- env",
-        "aws-okta --debug exec sym -- false",
-        "aws-okta exec sym -- true",
-        "aws-okta exec sym -- aws ssm start-session --target i-0123456789abcdef",
+        "aws-okta exec sym-catfood -- env",
+        "aws-okta --debug exec sym-catfood -- false",
+        "aws-okta exec sym-catfood -- true",
+        "aws-okta exec sym-catfood -- aws ssm start-session --target i-0123456789abcdef",
     )
 
 
@@ -33,19 +33,19 @@ def test_aws_okta_debug(
         with capture_command():
             aws_okta.exec("env")
     capture_command.assert_command(
-        "aws-okta --debug exec sym -- env",
-        "aws-okta --debug exec sym -- false",
-        "aws-okta --debug exec sym -- true",
-        "aws-okta --debug exec sym -- env",
+        "aws-okta --debug exec sym-catfood -- env",
+        "aws-okta --debug exec sym-catfood -- false",
+        "aws-okta --debug exec sym-catfood -- true",
+        "aws-okta --debug exec sym-catfood -- env",
     )
 
 
 def test_aws_okta_multi_threads(subprocess_friendly_asserter) -> None:
     commands = (
-        "aws-okta exec sym -- env",
-        "aws-okta --debug exec sym -- false",
-        "aws-okta exec sym -- true",
-        "aws-okta exec sym -- env",
+        "aws-okta exec sym-test -- env",
+        "aws-okta --debug exec sym-test -- false",
+        "aws-okta exec sym-test -- true",
+        "aws-okta exec sym-test -- env",
     )
     f, *args = subprocess_friendly_asserter
     with Pool(processes=4) as pool:
